@@ -29,7 +29,7 @@ def read_nem_file(file_path: str, ignore_missing_header=False) -> NEMFile:
     """ Read in NEM file and return meter readings named tuple
 
     :param file_path: The NEM file to process
-    :param ignore_missing_header: Whether to continue parsing if missing header. 
+    :param ignore_missing_header: Whether to continue parsing if missing header.
                                   Will assume NEM12 format.
     :returns: The file that was created
     """
@@ -156,9 +156,13 @@ def parse_nem12_rows(
 
         elif record_indicator == 300:
             num_intervals = int(24 * 60 / nmi_d.interval_length)
-            assert len(row) > num_intervals, "Incomplete 300 Row in {}".format(
-                file_name
-            )
+            assert len(row) > 1, f"Invalid 300 Row in {file_name}"
+            if len(row) < num_intervals + 2:
+                record_date = row[1]
+                msg = "Skipping 300 record for %s %s %s. "
+                msg += "It does not have the expected %s intervals"
+                log.error(msg, nmi_d.nmi, nmi_d.nmi_suffix, record_date, num_intervals)
+                continue
             interval_record = parse_300_row(
                 row, nmi_d.interval_length, nmi_d.uom, nmi_d.meter_serial_number
             )
@@ -244,8 +248,8 @@ def calculate_manual_reading(basic_data: BasicMeterData) -> Reading:
     """ Calculate the interval between two manual readings """
     t_start = basic_data.previous_register_read_datetime
     t_end = basic_data.current_register_read_datetime
-    read_start = basic_data.previous_register_read
-    read_end = basic_data.current_register_read
+    val_start = basic_data.previous_register_read
+    val_end = basic_data.current_register_read
     value = basic_data.quantity
 
     meter_serial_number = basic_data.meter_serial_number
@@ -261,8 +265,8 @@ def calculate_manual_reading(basic_data: BasicMeterData) -> Reading:
         quality_method,
         "",
         "",
-        read_start,
-        read_end,
+        val_start,
+        val_end,
     )
 
 
@@ -372,8 +376,8 @@ def parse_interval_records(
             meter_serial_number=meter_serial_number,
             event_code=event_code,  # This may get changed later by a 400 row
             event_desc=event_desc,  # This may get changed later by a 400 row
-            read_start=None,
-            read_end=None,  # No before and after readings for intervals
+            val_start=None,
+            val_end=None,  # No before and after readings for intervals
         )
         for i, val in enumerate(interval_record)
     ]
@@ -409,8 +413,8 @@ def update_reading_events(readings, event_record):
             quality_method=event_record.quality_method,
             event_code=event_record.reason_code,
             event_desc=event_record.reason_description,
-            read_start=readings[i].read_start,
-            read_end=readings[i].read_end,
+            val_start=readings[i].val_start,
+            val_end=readings[i].val_end,
         )
     return readings
 
